==> docfbe_2_2_31_55.zip: docfbe_2_2_31_55/source/TCFbECorrelationCoefficientWithMedian.cpp <==
/*
    TCFbECorrelationCoefficientWithMedian.cpp    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbECorrelationCoefficientWithMedian.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbECorrelationCoefficientWithMedian::TCFbECorrelationCoefficientWithMedian(void)
    : TCFbECosineSimilarity()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbECorrelationCoefficientWithMedian::~TCFbECorrelationCoefficientWithMedian()
{

}

//---------------------------------------------------------------------------
// vẐ߂̒l擾
double __fastcall TCFbECorrelationCoefficientWithMedian::GetValue(int RowIndex, int ColumnIndex)
{
    return this->DataSet->SimilarityComputationTable->CellsByIndex[RowIndex][ColumnIndex]->Value - this->DataSet->SimilarityComputationTable->GetMedianOfRow(RowIndex);
}

//---------------------------------------------------------------------------

==> docfbe_2_3_36_63.zip: docfbe_2_3_36_63/source/TCFbECorrelationCoefficientWithMedian.cpp <==
/*
    TCFbECorrelationCoefficientWithMedian.cpp    June 6, 2004.

    Copyright (C) 2003-2004 CFbE Research Group,
    Software Engineering Laboratory,
    Graduate School of Information Science,
    Nara Institute of Science and Technology,
    All rights reserved.

    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, (at your option) or
    any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GNU Emacs; see the file COPYING.  If not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/
//---------------------------------------------------------------------------
#pragma hdrstop

#include "TCFbECorrelationCoefficientWithMedian.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
//---------------------------------------------------------------------------
// RXgN^
__fastcall TCFbECorrelationCoefficientWithMedian::TCFbECorrelationCoefficientWithMedian(void)
    : TCFbECosineSimilarity()
{
}

//---------------------------------------------------------------------------
// fXgN^
__fastcall TCFbECorrelationCoefficientWithMedian::~TCFbECorrelationCoefficientWithMedian()
{

}

//---------------------------------------------------------------------------
// vẐ߂̒l擾
double __fastcall TCFbECorrelationCoefficientWithMedian::GetValue(int RowIndex, int ColumnIndex)
{
    return this->SimilarityComputationTable->GetCellByIndex(RowIndex, ColumnIndex)->GetValue() - this->SimilarityComputationTable->GetMedianOfRow(RowIndex);
}

//---------------------------------------------------------------------------
